@use "sass:color";

$highlight-color: #dd823b;

@use "../_admin.scss" with (
  $scheme-name: "sunrise",
  $base-color: #cf4944,
  $highlight-color: $highlight-color,
  $notification-color: #ccaf0b,
  $menu-submenu-focus-text: color.adjust($highlight-color, $lightness: 35%)
);
