@use "sass:color";

$highlight-color: #3858e9;

@use "../_admin.scss" with (
	$scheme-name: "modern",
	$base-color: #1e1e1e,
	$highlight-color: #3858e9,
	$menu-submenu-focus-text: #7b90ff,
	$notification-color: $highlight-color,

	$link: $highlight-color,
	$link-focus: color.adjust($highlight-color, $lightness: -10%),

	$custom-welcome-panel: "false"
);
